@@ -21,7 +21,7 @@
 
 class DocumentationViewer : public TDEHTMLPart
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
