@@ -60,7 +60,7 @@ namespace KileHelp
 
 	class Help : public TQObject
 	{
-		Q_OBJECT
+		TQ_OBJECT
   
 
 	public:
