@@ -118,7 +118,7 @@ class JScriptEnvironment {
  * This class handles the scripting functionality in Kile.
  **/
 class Manager : public TQObject {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
@@ -263,7 +263,7 @@ class Manager : public TQObject {
 };
 
 class ScriptExecutionAction : public TDEAction {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
